import {connect} from "react-redux";
import styled from 'styled-components';
import {useEffect, useState} from "react";
import {setActiveUserAllPostsAsync, setUserDataAsync} from "../store/actionCreators/ActionCreators";
import avatar from "../assets/img/avatarGolub.jpg";
import picture from "../assets/img/brokenPicture.png";
import ModalWindow from "./ModalWindow";
import AutoAwesomeMotionIcon from '@mui/icons-material/AutoAwesomeMotion';
import Carousel from 'react-material-ui-carousel'
import CommentsBlock from "./CommentsBlock"
import AvaLoginBlock from "./AvaLoginBlock";

const UserContentWrapper = styled.div`
  margin-top: 30px;
  width: 100%;
  display: flex;
  align-items: center;
  flex-direction: column;
`
const AvatarBlock = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  align-items: center;
  margin-right: 100px;
`
const PostsContainer = styled.div`
  display: flex;
  flex-direction: row;
  max-width: 1000px;
  flex-wrap: wrap;
  justify-content: center;
`
const UserInfoWrapper = styled.div`
  display: flex;
  width: 1000px;
  justify-content: center;
  margin-bottom: 30px;
  padding-bottom: 20px;
`
const UserInfoBlockWrapper = styled.div`
  display: flex;
  justify-content: flex-start;
`
const UserInfoBlockStyled = styled.div`
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 0 40px;
  flex-direction: column;
`
const AvatarWrapper = styled.div`
  width: 100px;
  height: 100px;
  border-radius: 50%;
  border: 1px solid grey;
  overflow: hidden;
  display: flex;
  align-items: center;
`
const PostWrapper = styled.div`
  position: relative;
  display: flex;
  min-width: 300px;
  max-width: 300px;
  margin: 15px;
  box-shadow: rgba(0, 0, 0, 0.25) 0px 0.0625em 0.0625em, rgba(0, 0, 0, 0.25) 0px 0.125em 0.5em, rgba(255, 255, 255, 0.1) 0px 0px 0px 1px inset;
`
const LogoManyImg = styled.div`
  position: absolute;
  z-index: 2;
  right: 0;
  width: 25px;
  height: 35px;
  transform: scaleX(-1);
`
const PicsInModalWrapper = styled.div`
  width: 50%;
  max-height: 100%;
  margin: 30px;
  overflow: hidden;
  display: flex;
  align-items: center;
  justify-content: center;
  box-shadow: rgba(0, 0, 0, 0.25) 0px 0.0625em 0.0625em, rgba(0, 0, 0, 0.25) 0px 0.125em 0.5em, rgba(255, 255, 255, 0.1) 0px 0px 0px 1px inset;
`
const AvaLoginWrap = styled.div`
  display: flex;
  margin-top: 30px;
  width: 80%;

`
const DescriptionPostWrapper = styled.div`
  height: fit-content;
  width: 100%;
  box-shadow: rgba(17, 17, 26, 0.1) 0px 1px 0px;
`
const InfoBlockInModalWrapper = styled.div`
  width: 50%;
`
const Title = styled.p``
const Text = styled.p``
const tempUser = "62c1cc5e4535fc62e2a185ad"; // test - should be deleted


function UserContent(props) {

    const [likes, setLikes] = useState(null);

    useEffect(() => {
        if (!props.activeUser) {
            props.setUserDataAsync(props.id)
        }
        if (props.activeUser && !props.activeUserPosts.length) {

            // props.setActiveUserAllPostsAsync(tempUser);
            props.setActiveUserAllPostsAsync(props.activeUser._id)
        }
    })

    const UserInfoBlock = ({count, description}) => {
        return (<UserInfoBlockStyled>
            <p>{count ? count : 0}</p>
            <p>{description}</p>
        </UserInfoBlockStyled>)
    }
    const Post = ({post}) => {
        const [isModal, setModal] = useState(false)
        console.log(post)
        function toggleModalWindow() {
            setModal(!isModal)
        }

        const ImgBlock = ({images}) => {
            return (
                <>
                    {!images && <img src={picture} alt={"pic"}/>}
                    {images && images.length === 1 && <img src={images[0].url} alt={"pic"} style={{width: "100%"}}/>}
                    {images && images.length > 1 && <div style={{width: "100%"}}>
                        <Carousel autoPlay={false} navButtonsAlwaysVisible={true}>{
                            images.map((item, i) => <img src={item.url} key={i} style={{width: "100%"}}
                                                         alt={"picture"}/>)
                        }
                        </Carousel>
                    </div>}
                </>
                // (images?.length && images.length > 1) && console.log("many pics") || (images && images.length === 1) &&
                //  <img src={images[0].url} alt={"pic"} style={{width:"100%"}}/> || <img src={picture} alt={"pic"}/>
                // <img src={images[0].url} alt={"pic"}/>
            )
        };

        console.log(post)
        return (
            <PostWrapper onClick={() => toggleModalWindow()}>
                <img src={post.images ? post.images[0].url : picture} alt="post" style={{width: "100%"}}/>
                {
                    post.images?.length > 1 && <LogoManyImg>
                        <AutoAwesomeMotionIcon/>
                    </LogoManyImg>
                }
                {isModal &&
                <ModalWindow closeModal={toggleModalWindow}>
                    <PicsInModalWrapper>
                        <ImgBlock images={post.images}/>
                    </PicsInModalWrapper>
                    <InfoBlockInModalWrapper>

                        <AvaLoginWrap>
                            <AvaLoginBlock urlAva={props.activeUser.avatar.url} name={props.activeUser.login}/>

                        </AvaLoginWrap>
                        <DescriptionPostWrapper>
                            <Title>Title:{post.title}</Title>
                            <Text>{post.text}</Text>
                        </DescriptionPostWrapper>

                        <CommentsBlock id={post._id} setLikes={setLikes} isLikesRendered={likes !== null}/>
                        {/*<LikeBlock/>*/}

                    </InfoBlockInModalWrapper>
                </ModalWindow>
                }
            </PostWrapper>
        )
    }
    return (
        <>
            {props.activeUser && <UserContentWrapper>
                <UserInfoWrapper>
                    <AvatarBlock>
                        <AvatarWrapper>
                            <img style={{height: "100%"}}
                                 src={props.activeUser && props.activeUser.avatar ? props.activeUser.avatar.url : avatar}
                                 alt={"avatar"}/>
                        </AvatarWrapper>
                        <h2>{props.activeUser.login}</h2>
                    </AvatarBlock>
                    <UserInfoBlockWrapper>
                        <UserInfoBlock count={props.activeUserPosts?.length} description={"posts"}/>
                        <UserInfoBlock count={props.activeUser.followers?.length} description={"followers"}/>
                        <UserInfoBlock count={props.activeUser.following?.length} description={"followings"}/>
                    </UserInfoBlockWrapper>
                </UserInfoWrapper>

                {props.activeUserPosts &&
                <PostsContainer>
                    {props.activeUserPosts.map((post, index) => <Post post={post} key={index}/>)}
                </PostsContainer>}
            </UserContentWrapper>
            }
        </>
    )
}

;

const mapStateToProps = (state) => {
    return {
        id: state.auth.user.sub.id,
        activeUser: state.activeUser,
        activeUserPosts: state.activeUserPosts,
    }
}

const mapDispatchToProps = (dispatch) => {
    return {
        setUserDataAsync: (id) => dispatch(setUserDataAsync(id)),
        setActiveUserAllPostsAsync: (id) => dispatch(setActiveUserAllPostsAsync(id)),
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(UserContent);